%bcond_with python_bootstrap
%bcond_with doc

Summary:        A high-level Python Web framework
Name:           python-django
Version:        3.2.24
Release:        1%{?dist}
License:        BSD
URL:            https://www.djangoproject.com/
Source0:        https://github.com/django/django/archive/refs/tags/django-%{version}.tar.gz

Patch0001:      Add-Python-3.11-support-for-tests.patch
Patch0002:      Fix-url-validator.patch
Patch0003:      2d2c1d0c97832860fbd6597977e2aae17dd7e5b2.patch
Patch0004:      15168.patch
Patch0005:      b61f44c339830ea53663415f00cbd17e2fd5aa43.patch
Patch0006:      36fa071d6ebd18a61c4d7f1b5c9d17106134bd44.patch

BuildArch:      noarch

 
%description
Django is a high-level Python web framework that encourages rapid development
and clean, pragmatic design. Built by experienced developers, it takes care of
much of the hassle of web development, so you can focus on writing your app
without needing to reinvent the wheel. It’s free and open source.

 
%package bash-completion
Summary:        Bash completion files for Django
BuildRequires:  bash-completion
Requires:       bash-completion
 
%description bash-completion
This package contains the Bash completion files form Django high-level
Python Web framework.


%if %{with doc}
%package -n python3-django-doc
Summary:        Documentation for Django
BuildRequires:  make
Suggests:       python3-django = %{version}-%{release}
 
%description -n python3-django-doc
This package contains the documentation for the Django high-level
Python Web framework.
%endif


%package -n python3-django
Summary:        A high-level Python Web framework
BuildRequires: python3-devel python3-setuptools python3-pytz python3-sqlparse python-selenium python3-sphinx
BuildRequires: /usr/bin/pathfix.py python3-asgiref
Requires:      python3-pytz python3-sqlparse python3-argon2-cffi python3-bcrypt
Provides:      python-Django, python3-django
 
%description -n python3-django
Django is a high-level Python web framework that encourages rapid development
and clean, pragmatic design. Built by experienced developers, it takes care of
much of the hassle of web development, so you can focus on writing your app
without needing to reinvent the wheel. It’s free and open source.


%prep
%autosetup -n django-%{version} -p1

pathfix.py -pni "%{__python3} %{py3_shbang_opts}" .
 
%build
%py3_build

 
%install
%py3_install
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" %{buildroot}/usr/lib/python%{python3_version}/site-packages/django/conf/project_template/manage.py-tpl

%if %{with doc}
(cd docs && mkdir djangohtml && mkdir -p _build/{doctrees,html} && make html)
cp -ar docs ..
%endif
 
mkdir -p %{buildroot}%{_mandir}/man1/
cp -p docs/man/* %{buildroot}%{_mandir}/man1/
 
bashcompdir=$(pkg-config --variable=completionsdir bash-completion)
mkdir -p %{buildroot}$bashcompdir
install -m 0644 -p extras/django_bash_completion \
  %{buildroot}$bashcompdir/django-admin.py
 
for file in django-admin django-admin-3 django-admin-%{python3_version} python3-django-admin manage.py ; do
   ln -s django-admin.py %{buildroot}$bashcompdir/$file
done
 
ln -s ./django-admin %{buildroot}%{_bindir}/django-admin-3
ln -s ./django-admin %{buildroot}%{_bindir}/django-admin-%{python3_version}
ln -s ./django-admin %{buildroot}%{_bindir}/python3-django-admin
 
find %{buildroot} -name "*.po" -delete


%check
cd %{_builddir}/django-%{version}
export PYTHONPATH="$(pwd):%{?with_python_bootstrap:$PYTHONPATH}"
cd tests
python3 runtests.py --settings=test_sqlite --verbosity=2 --parallel 1
 
 
%files bash-completion
%{_datadir}/bash-completion
 
%if %{with doc}
%files -n python3-django-doc
%doc docs/_build/html/*
%endif
 
%files -n python3-django
%license LICENSE
%doc AUTHORS README.rst
%{_bindir}/django-admin
%{_bindir}/django-admin-3
%{_bindir}/django-admin-%{python3_version}
%{_bindir}/python3-django-admin
%{_bindir}/django-admin.py
%{python3_sitelib}/*
%{_mandir}/man1/django-admin.1*
 
 
%changelog
* Sun Apr 07 2024 Shop You <shopyou@tencent.com> - 3.2.24-1
- Upgrade to version 3.2.24

* Tue Mar 19 2024 Shop You <shopyou@tencent.com> - 3.2-2
- Add patches to fix CVE-2021-45115,CVE-2022-34265

* Sat Oct 07 2023 Miaojun Dong <zoedong@tencent.com> - 3.2-1
- Downgrade version to 3.2 to meet openstack-dashboard-23.0.0 Requirement

* Thu Sep 28 2023 cunshunxia <cunshunxia@tencent.com> - 4.2.5-1
- Upgrade to version 4.2.5

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.28-6
- Rebuilt for python 3.11

* Thu Sep 14 2023 Shuo Wang <abushwang@tencent.com> - 2.2.28-5
- use %setup for bootstrap

* Thu Sep 14 2023 Shuo Wang <abushwang@tencent.com> - 2.2.28-4
- bypass many test for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.28-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.28-2
- Rebuilt for OpenCloudOS Stream 23.05

* Sun Apr 23 2023 Miaojun Dong <zoedong@tencent.com> - 2.2.28-1
- initial build
